package logic

//登录回调
import (
	"fusenapi/constants"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/websocket/internal/svc"
	"fusenapi/server/websocket/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type LoginNotifyLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewLoginNotifyLogic(ctx context.Context, svcCtx *svc.ServiceContext) *LoginNotifyLogic {
	return &LoginNotifyLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *LoginNotifyLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *LoginNotifyLogic) LoginNotify(req *types.LoginNotifyReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	if req.Data.WebsocketConnId == "" {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "参数错误，连接标识不能为空")
	}
	value, ok := mapConnPool.Load(req.Data.WebsocketConnId)
	if !ok {
		return resp.SetStatusWithMessage(basic.CodeOK, "success,but connection is not found")
	}
	ws, ok := value.(wsConnectItem)
	if !ok {
		logx.Error("渲染回调断言websocket连接失败")
		return resp.SetStatusWithMessage(basic.CodeServiceErr, "断言连接错误")
	}
	//发送消息到出口缓冲池
	ws.sendToOutChan(ws.respondDataFormat(constants.WEBSOCKET_LOGIN_NOTIFY, req.Data.Info))
	return resp.SetStatusWithMessage(basic.CodeOK, "success")
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *LoginNotifyLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
